@@ -26,12 +26,11 @@
 #include "eckit/memory/Counted.h"
 #include "eckit/value/Value.h"
 
+#include "metkit/mars/MarsExpandContext.h"
 #include "metkit/mars/MarsRequest.h"
 
 namespace metkit::mars {
 
-class MarsExpandContext;
-
 //----------------------------------------------------------------------------------------------------------------------
 
 /// @brief abstract class - ContextRule subclasses are used to define a context. A MarsRequest matches a context, if it
@@ -188,13 +187,12 @@ public:  // methods
 
     ~Type() noexcept override = default;
 
+    virtual bool expand(const MarsExpandContext& ctx, std::string& value, const MarsRequest& request = {}) const;
     virtual void expand(const MarsExpandContext& ctx, std::vector<std::string>& values,
                         const MarsRequest& request = {}) const;
-    virtual bool expand(const MarsExpandContext& ctx, std::string& value, const MarsRequest& request = {}) const;
 
-    std::string tidy(const MarsExpandContext& ctx, const std::string& value, const MarsRequest& request = {}) const;
-    std::string tidy(const std::string& value, const MarsRequest& request = {}) const;
-    std::vector<std::string> tidy(const std::vector<std::string>& values, const MarsRequest& request = {}) const;
+    std::string tidy(const std::string& value, const MarsExpandContext& ctx = DummyContext{},
+                     const MarsRequest& request = {}) const;
 
     virtual void setDefaults(MarsRequest& request);
     virtual void setInheritance(const std::vector<std::string>& inheritance);
@@ -221,6 +219,11 @@ public:  // methods
 
     virtual size_t count(const std::vector<std::string>& values) const;
 
+protected:  // methods
+
+    virtual bool hasGroups() const { return false; }
+    virtual const std::vector<std::string>& group(const std::string&) const { NOTIMP; }
+
 protected:  // members
 
     std::string name_;
